@@ -23,10 +23,10 @@
  *          Sebastian Dröge <slomo@circular-chaos.org>
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "gfamdirectorymonitor.h"
-#include "giomodule.h"
+#include <gio/giomodule.h>
 
 #include "fam-helper.h"
 
