@@ -29,6 +29,9 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#ifdef _WIN32
+#include <io.h>
+#endif
 
 #include <glib/gstdio.h>
 
@@ -40,7 +43,6 @@
 #include "gdbusprivate.h"
 
 #include "glibintl.h"
-#include "gioalias.h"
 
 struct _GDBusAuthMechanismSha1Private
 {
@@ -281,7 +283,9 @@ ensure_keyring_directory (GError **error)
               goto out;
             }
 #else
+#ifdef __GNUC__
 #warning Please implement permission checking on this non-UNIX platform
+#endif
 #endif
         }
         goto out;
@@ -355,8 +359,8 @@ keyring_lookup_entry (const gchar  *cookie_context,
   guint n;
   gchar **lines;
 
-  g_return_val_if_fail (cookie_context != NULL, FALSE);
-  g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
+  g_return_val_if_fail (cookie_context != NULL, NULL);
+  g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
   ret = NULL;
   path = NULL;
@@ -1212,6 +1216,3 @@ mechanism_client_shutdown (GDBusAuthMechanism   *mechanism)
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
-
-#define __G_DBUS_AUTH_MECHANISM_SHA1_C__
-#include "gioaliasdef.c"
