@@ -32,7 +32,6 @@
 #include "gdbusprivate.h"
 
 #include "glibintl.h"
-#include "gioalias.h"
 
 /**
  * SECTION:gdbuserror
@@ -152,12 +151,12 @@ static const GDBusErrorEntry g_dbus_error_entries[] =
 GQuark
 g_dbus_error_quark (void)
 {
+  G_STATIC_ASSERT (G_N_ELEMENTS (g_dbus_error_entries) - 1 == G_DBUS_ERROR_OBJECT_PATH_IN_USE);
   static volatile gsize quark_volatile = 0;
   g_dbus_error_register_error_domain ("g-dbus-error-quark",
                                       &quark_volatile,
                                       g_dbus_error_entries,
                                       G_N_ELEMENTS (g_dbus_error_entries));
-  G_STATIC_ASSERT (G_N_ELEMENTS (g_dbus_error_entries) - 1 == G_DBUS_ERROR_OBJECT_PATH_IN_USE);
   return (GQuark) quark_volatile;
 }
 
@@ -434,10 +433,13 @@ g_dbus_error_unregister_error (GQuark       error_domain,
       g_warn_if_fail (g_hash_table_lookup (quark_code_pair_to_re, &pair) == NULL); /* check invariant */
       goto out;
     }
+
+  ret = TRUE;
+
   g_warn_if_fail (g_hash_table_lookup (quark_code_pair_to_re, &(re->pair)) == re); /* check invariant */
 
   g_warn_if_fail (g_hash_table_remove (quark_code_pair_to_re, &(re->pair)));
-  g_warn_if_fail (g_hash_table_remove (dbus_error_name_to_re, re));
+  g_warn_if_fail (g_hash_table_remove (dbus_error_name_to_re, re->dbus_error_name));
 
   /* destroy hashes if empty */
   hash_size = g_hash_table_size (dbus_error_name_to_re);
@@ -868,6 +870,3 @@ g_dbus_error_encode_gerror (const GError *error)
 
   return error_name;
 }
-
-#define __G_DBUS_ERROR_C__
-#include "gioaliasdef.c"
