@@ -31,7 +31,6 @@
 #include "gioerror.h"
 #include "glibintl.h"
 
-#include "gioalias.h"
 
 /**
  * SECTION:gfileinputstream
@@ -467,7 +466,3 @@ g_file_input_stream_real_query_info_finish (GFileInputStream  *stream,
   
   return NULL;
 }
-
-#define __G_FILE_INPUT_STREAM_C__
-#include "gioaliasdef.c"
-
