@@ -24,7 +24,6 @@
 #include <errno.h>
 #include "gioerror.h"
 
-#include "gioalias.h"
 
 /**
  * SECTION:gioerror
@@ -138,7 +137,7 @@ g_io_error_from_errno (gint err_no)
       break;
 #endif
 
-#ifdef ENOTEMPTY
+#if defined(ENOTEMPTY) && (!defined (EEXIST) || (ENOTEMPTY != EEXIST))
     case ENOTEMPTY:
       return G_IO_ERROR_NOT_EMPTY;
       break;
@@ -194,11 +193,41 @@ g_io_error_from_errno (gint err_no)
       break;
 #endif
 
+#ifdef EADDRINUSE
+    case EADDRINUSE:
+      return G_IO_ERROR_ADDRESS_IN_USE;
+      break;
+#endif
+
     default:
       return G_IO_ERROR_FAILED;
       break;
     }
 }
 
-#define __G_IO_ERROR_C__
-#include "gioaliasdef.c"
+#ifdef G_OS_WIN32
+
+/**
+ * g_io_error_from_win32_error:
+ * @error_code: Windows error number.
+ *
+ * Converts some common error codes into GIO error codes. The
+ * fallback value G_IO_ERROR_FAILED is returned for error codes not
+ * handled.
+ *
+ * Returns: #GIOErrorEnum value for the given error number.
+ *
+ * Since: 2.26
+ **/
+GIOErrorEnum
+g_io_error_from_win32_error (gint error_code)
+{
+  switch (error_code)
+    {
+    default:
+      return G_IO_ERROR_FAILED;
+      break;
+    }
+}
+
+#endif
