@@ -681,6 +681,7 @@ enum
 {
   PROP_0,
   PROP_BOOL,
+  PROP_ANTI_BOOL,
   PROP_BYTE,
   PROP_INT16,
   PROP_UINT16,
@@ -701,6 +702,7 @@ typedef struct
   GObject parent_instance;
 
   gboolean bool_prop;
+  gboolean anti_bool_prop;
   gchar byte_prop;
   gint int16_prop;
   guint16 uint16_prop;
@@ -750,6 +752,9 @@ test_object_get_property (GObject    *object,
     case PROP_BOOL:
       g_value_set_boolean (value, test_object->bool_prop);
       break;
+    case PROP_ANTI_BOOL:
+      g_value_set_boolean (value, test_object->anti_bool_prop);
+      break;
     case PROP_BYTE:
       g_value_set_char (value, test_object->byte_prop);
       break;
@@ -805,6 +810,9 @@ test_object_set_property (GObject      *object,
     case PROP_BOOL:
       test_object->bool_prop = g_value_get_boolean (value);
       break;
+    case PROP_ANTI_BOOL:
+      test_object->anti_bool_prop = g_value_get_boolean (value);
+      break;
     case PROP_BYTE:
       test_object->byte_prop = g_value_get_char (value);
       break;
@@ -883,6 +891,8 @@ test_object_class_init (TestObjectClass *class)
 
   g_object_class_install_property (gobject_class, PROP_BOOL,
     g_param_spec_boolean ("bool", "", "", FALSE, G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_ANTI_BOOL,
+    g_param_spec_boolean ("anti-bool", "", "", FALSE, G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, PROP_BYTE,
     g_param_spec_char ("byte", "", "", G_MININT8, G_MAXINT8, 0, G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, PROP_INT16,
@@ -942,7 +952,6 @@ test_simple_binding (void)
   obj = test_object_new ();
 
   g_settings_bind (settings, "bool", obj, "bool", G_SETTINGS_BIND_DEFAULT);
-
   g_object_set (obj, "bool", TRUE, NULL);
   g_assert_cmpint (g_settings_get_boolean (settings, "bool"), ==, TRUE);
 
@@ -951,6 +960,16 @@ test_simple_binding (void)
   g_object_get (obj, "bool", &b, NULL);
   g_assert_cmpint (b, ==, FALSE);
 
+  g_settings_bind (settings, "anti-bool", obj, "anti-bool",
+                   G_SETTINGS_BIND_INVERT_BOOLEAN);
+  g_object_set (obj, "anti-bool", FALSE, NULL);
+  g_assert_cmpint (g_settings_get_boolean (settings, "anti-bool"), ==, TRUE);
+
+  g_settings_set_boolean (settings, "anti-bool", FALSE);
+  b = FALSE;
+  g_object_get (obj, "anti-bool", &b, NULL);
+  g_assert_cmpint (b, ==, TRUE);
+
   g_settings_bind (settings, "byte", obj, "byte", G_SETTINGS_BIND_DEFAULT);
 
   g_object_set (obj, "byte", 123, NULL);
@@ -1737,6 +1756,28 @@ test_list_items (void)
   g_object_unref (settings);
 }
 
+static void
+test_list_schemas (void)
+{
+  const gchar * const *schemas;
+
+  schemas = g_settings_list_schemas ();
+
+  g_assert (strv_set_equal ((const gchar **)schemas,
+                            "org.gtk.test",
+                            "org.gtk.test.no-path",
+                            "org.gtk.test.basic-types",
+                            "org.gtk.test.complex-types",
+                            "org.gtk.test.localized",
+                            "org.gtk.test.binding",
+                            "org.gtk.test.enums",
+                            "org.gtk.test.enums.direct",
+                            "org.gtk.test.range",
+                            "org.gtk.test.range.direct",
+                            "org.gtk.test.mapped",
+                            NULL));
+}
+
 static gboolean
 map_func (GVariant *value,
           gpointer *result,
@@ -1800,6 +1841,7 @@ main (int argc, char *argv[])
 
   backend_set = g_getenv ("GSETTINGS_BACKEND") != NULL;
 
+  g_setenv ("XDG_DATA_DIRS", ".", TRUE);
   g_setenv ("GSETTINGS_SCHEMA_DIR", ".", TRUE);
 
   if (!backend_set)
@@ -1870,6 +1912,7 @@ main (int argc, char *argv[])
   g_test_add_func ("/gsettings/flags", test_flags);
   g_test_add_func ("/gsettings/range", test_range);
   g_test_add_func ("/gsettings/list-items", test_list_items);
+  g_test_add_func ("/gsettings/list-schemas", test_list_schemas);
   g_test_add_func ("/gsettings/mapped", test_get_mapped);
 
   result = g_test_run ();
